@@ -1,12 +1,14 @@
 """
 Use mitmproxy's filter pattern in scripts.
 """
+
 from __future__ import annotations
 
 import logging
 
 from mitmproxy import flowfilter
 from mitmproxy import http
+from mitmproxy.addonmanager import Loader
 
 
 class Filter:
@@ -16,8 +18,8 @@ class Filter:
         if "flowfilter" in updated:
             self.filter = flowfilter.parse(".")
 
-    def load(self, l):
-        l.add_option("flowfilter", str, "", "Check that flow matches filter.")
+    def load(self, loader: Loader):
+        loader.add_option("flowfilter", str, "", "Check that flow matches filter.")
 
     def response(self, flow: http.HTTPFlow) -> None:
         if flowfilter.match(self.filter, flow):
