@@ -5,7 +5,6 @@ from mitmproxy import optmanager
 
 CONF_DIR = "~/.mitmproxy"
 CONF_BASENAME = "mitmproxy"
-LISTEN_PORT = 8080
 CONTENT_VIEW_LINES_CUTOFF = 512
 KEY_SIZE = 2048
 
@@ -20,7 +19,20 @@ class Options(optmanager.OptManager):
             "showhost",
             bool,
             False,
-            "Use the Host header to construct URLs for display.",
+            """Use the Host header to construct URLs for display.
+
+            This option is disabled by default because malicious apps may send misleading host headers to evade
+            your analysis. If this is not a concern, enable this options for better flow display.""",
+        )
+        self.add_option(
+            "show_ignored_hosts",
+            bool,
+            False,
+            """
+            Record ignored flows in the UI even if we do not perform TLS interception.
+            This option will keep ignored flows' contents in memory, which can greatly increase memory usage.
+            A future release will fix this issue, record ignored flows by default, and remove this option.
+            """,
         )
 
         # Proxy options
@@ -63,18 +75,6 @@ class Options(optmanager.OptManager):
             process list. Specify it in config.yaml to avoid this.
             """,
         )
-        self.add_option(
-            "ciphers_client",
-            Optional[str],
-            None,
-            "Set supported ciphers for client <-> mitmproxy connections using OpenSSL syntax.",
-        )
-        self.add_option(
-            "ciphers_server",
-            Optional[str],
-            None,
-            "Set supported ciphers for mitmproxy <-> server connections using OpenSSL syntax.",
-        )
         self.add_option(
             "client_certs", Optional[str], None, "Client certificate file or directory."
         )
@@ -91,16 +91,34 @@ class Options(optmanager.OptManager):
             """,
         )
         self.add_option("allow_hosts", Sequence[str], [], "Opposite of --ignore-hosts.")
-        self.add_option("listen_host", str, "", "Address to bind proxy to.")
-        self.add_option("listen_port", int, LISTEN_PORT, "Proxy service port.")
+        self.add_option(
+            "listen_host",
+            str,
+            "",
+            "Address to bind proxy server(s) to (may be overridden for individual modes, see `mode`).",
+        )
+        self.add_option(
+            "listen_port",
+            Optional[int],
+            None,
+            "Port to bind proxy server(s) to (may be overridden for individual modes, see `mode`). "
+            "By default, the port is mode-specific. The default regular HTTP proxy spawns on port 8080.",
+        )
         self.add_option(
             "mode",
-            str,
-            "regular",
+            Sequence[str],
+            ["regular"],
             """
-            Mode can be "regular", "transparent", "socks5", "reverse:SPEC",
-            or "upstream:SPEC". For reverse and upstream proxy modes, SPEC
-            is host specification in the form of "http[s]://host[:port]".
+            The proxy server type(s) to spawn. Can be passed multiple times.
+
+            Mitmproxy supports "regular" (HTTP), "transparent", "socks5", "reverse:SPEC",
+            "upstream:SPEC", and "wireguard[:PATH]" proxy servers. For reverse and upstream proxy modes, SPEC
+            is host specification in the form of "http[s]://host[:port]". For WireGuard mode, PATH may point to
+            a file containing key material. If no such file exists, it will be created on startup.
+
+            You may append `@listen_port` or `@listen_host:listen_port` to override `listen_host` or `listen_port` for
+            a specific proxy mode. Features such as client playback will use the first mode to determine
+            which upstream server to use.
             """,
         )
         self.add_option(
@@ -114,7 +132,7 @@ class Options(optmanager.OptManager):
             "http2",
             bool,
             True,
-            "Enable/disable HTTP/2 support. " "HTTP/2 support is enabled by default.",
+            "Enable/disable HTTP/2 support. HTTP/2 support is enabled by default.",
         )
         self.add_option(
             "http2_ping_keepalive",
@@ -126,6 +144,18 @@ class Options(optmanager.OptManager):
             Set to 0 to disable this feature.
             """,
         )
+        self.add_option(
+            "http3",
+            bool,
+            True,
+            "Enable/disable support for QUIC and HTTP/3. Enabled by default.",
+        )
+        self.add_option(
+            "http_connect_send_host_header",
+            bool,
+            True,
+            "Include host header with CONNECT requests. Enabled by default.",
+        )
         self.add_option(
             "websocket",
             bool,
@@ -144,7 +174,10 @@ class Options(optmanager.OptManager):
             "ssl_insecure",
             bool,
             False,
-            "Do not verify upstream server SSL/TLS certificates.",
+            """Do not verify upstream server SSL/TLS certificates.
+
+            If this option is enabled, certificate validation is skipped and mitmproxy itself will be vulnerable to
+            TLS interception.""",
         )
         self.add_option(
             "ssl_verify_upstream_trusted_confdir",
@@ -171,6 +204,16 @@ class Options(optmanager.OptManager):
             The communication contents are printed to the log in verbose mode.
             """,
         )
+        self.add_option(
+            "udp_hosts",
+            Sequence[str],
+            [],
+            """
+            Generic UDP SSL proxy mode for all hosts that match the pattern.
+            Similar to --ignore-hosts, but SSL connections are intercepted.
+            The communication contents are printed to the log in verbose mode.
+            """,
+        )
         self.add_option(
             "content_view_lines_cutoff",
             int,
@@ -188,5 +231,11 @@ class Options(optmanager.OptManager):
             TLS key size for certificates and CA.
             """,
         )
+        self.add_option(
+            "protobuf_definitions",
+            Optional[str],
+            None,
+            "Path to a .proto file that's used to resolve Protobuf field names when pretty-printing.",
+        )
 
         self.update(**kwargs)
