@@ -313,9 +313,7 @@ def test_ignore_payload_params():
         b = f"--{boundary}\n"
         parts = []
         for k, v in kwargs.items():
-            parts.append(
-                'Content-Disposition: form-data; name="%s"\n\n' "%s\n" % (k, v)
-            )
+            parts.append('Content-Disposition: form-data; name="%s"\n\n%s\n' % (k, v))
         c = b + b.join(parts) + b
         r.request.content = c.encode()
         r.request.headers["content-type"] = "multipart/form-data; boundary=" + boundary
@@ -325,6 +323,24 @@ def test_ignore_payload_params():
     thash(r, r2, multipart_setter)
 
 
+def test_runtime_modify_params():
+    s = serverplayback.ServerPlayback()
+    with taddons.context(s) as tctx:
+        r = tflow.tflow(resp=True)
+        r.request.path = "/test?param1=1"
+        r2 = tflow.tflow(resp=True)
+        r2.request.path = "/test"
+
+        s.load_flows([r])
+        hash = next(iter(s.flowmap.keys()))
+
+        tctx.configure(s, server_replay_ignore_params=["param1"])
+        hash_mod = next(iter(s.flowmap.keys()))
+
+        assert hash != hash_mod
+        assert hash_mod == s._hash(r2)
+
+
 def test_server_playback_full():
     s = serverplayback.ServerPlayback()
     with taddons.context(s) as tctx:
@@ -364,6 +380,45 @@ async def test_server_playback_kill():
         assert f.error
 
 
+async def test_server_playback_kill_new_option():
+    s = serverplayback.ServerPlayback()
+    with taddons.context(s) as tctx:
+        tctx.configure(s, server_replay_refresh=True, server_replay_extra="kill")
+
+        f = tflow.tflow()
+        f.response = mitmproxy.test.tutils.tresp(content=f.request.content)
+        s.load_flows([f])
+
+        f = tflow.tflow()
+        f.request.host = "nonexistent"
+        await tctx.cycle(s, f)
+        assert f.error
+
+
+@pytest.mark.parametrize(
+    "option,status",
+    [
+        ("204", 204),
+        ("400", 400),
+        ("404", 404),
+        ("500", 500),
+    ],
+)
+async def test_server_playback_404(option, status):
+    s = serverplayback.ServerPlayback()
+    with taddons.context(s) as tctx:
+        tctx.configure(s, server_replay_refresh=True, server_replay_extra=option)
+
+        f = tflow.tflow()
+        f.response = mitmproxy.test.tutils.tresp(content=f.request.content)
+        s.load_flows([f])
+
+        f = tflow.tflow()
+        f.request.host = "nonexistent"
+        s.request(f)
+        assert f.response.status_code == status
+
+
 def test_server_playback_response_deleted():
     """
     The server playback addon holds references to flows that can be modified by the user in the meantime.
