@@ -1,7 +1,11 @@
 from mitmproxy.net.dns import types
 
 
-def test_simple():
-    assert types.A == 1
+def test_to_str():
     assert types.to_str(types.A) == "A"
     assert types.to_str(0) == "TYPE(0)"
+
+
+def test_from_str():
+    assert types.from_str("A") == types.A
+    assert types.from_str("TYPE(0)") == 0
