@@ -1,12 +1,19 @@
 from pathlib import Path
 
-from OpenSSL import crypto
+import pytest
 from OpenSSL import SSL
 
 from mitmproxy import certs
 from mitmproxy.net import tls
 
 
+@pytest.mark.parametrize("version", [tls.Version.UNBOUNDED, tls.Version.SSL3])
+def test_supported(version):
+    # wild assumption: test environments should not do SSLv3 by default.
+    expected_support = version is tls.Version.UNBOUNDED
+    assert tls.is_supported_version(version) == expected_support
+
+
 def test_make_master_secret_logger():
     assert tls.make_master_secret_logger(None) is None
     assert isinstance(tls.make_master_secret_logger("filepath"), tls.MasterSecretLogger)
@@ -52,8 +59,8 @@ def test_sslkeylogfile(tdata, monkeypatch):
     server = SSL.Connection(sctx)
     server.set_accept_state()
 
-    server.use_certificate(entry.cert.to_pyopenssl())
-    server.use_privatekey(crypto.PKey.from_cryptography_key(entry.privatekey))
+    server.use_certificate(entry.cert.to_cryptography())
+    server.use_privatekey(entry.privatekey)
 
     client = SSL.Connection(cctx)
     client.set_connect_state()
