@@ -1,13 +1,9 @@
-import asyncio
-
 from mitmproxy.tools import main
 
-
 shutdown_script = "mitmproxy/data/addonscripts/shutdown.py"
 
 
-def test_mitmweb(event_loop, tdata):
-    asyncio.set_event_loop(event_loop)
+def test_mitmweb(tdata):
     main.mitmweb(
         [
             "--no-web-open-browser",
@@ -22,8 +18,7 @@ def test_mitmweb(event_loop, tdata):
     )
 
 
-def test_mitmdump(event_loop, tdata):
-    asyncio.set_event_loop(event_loop)
+def test_mitmdump(tdata):
     main.mitmdump(
         [
             "-s",
