@@ -48,19 +48,19 @@ test("CommandBar", async () => {
                 return_type: null,
                 signature_help: "flow.encode flows part encoding",
             },
-        })
+        }),
     );
     fetchMock.mockOnceIf(
         "./commands/commands.history.get",
-        JSON.stringify({ value: ["foo"] })
+        JSON.stringify({ value: ["foo"] }),
     );
     fetchMock.mockOnceIf(
         "./commands/commands.history.add",
-        JSON.stringify({ value: null })
+        JSON.stringify({ value: null }),
     );
     fetchMock.mockOnceIf(
         "./commands/flow.encode",
-        JSON.stringify({ value: null })
+        JSON.stringify({ value: null }),
     );
 
     const { asFragment } = render(<CommandBar />);
@@ -70,29 +70,29 @@ test("CommandBar", async () => {
 
     const input = screen.getByPlaceholderText("Enter command");
 
-    userEvent.type(input, "x");
+    await userEvent.type(input, "x");
     expect(screen.getByText("[]")).toBeInTheDocument();
-    userEvent.type(input, "{backspace}");
+    await userEvent.type(input, "{backspace}");
 
-    userEvent.type(input, "fl");
-    userEvent.tab();
+    await userEvent.type(input, "fl");
+    await userEvent.tab();
     expect(input).toHaveValue("flow.decode");
-    userEvent.tab();
+    await userEvent.tab();
     expect(input).toHaveValue("flow.encode");
 
     fetchMock.mockOnce(JSON.stringify({ value: null }));
-    userEvent.type(input, "{enter}");
+    await userEvent.type(input, "{enter}");
     await waitFor(() => screen.getByText("Command Result"));
 
-    userEvent.type(input, "{arrowdown}");
+    await userEvent.type(input, "{arrowdown}");
     expect(input).toHaveValue("");
 
-    userEvent.type(input, "{arrowup}");
+    await userEvent.type(input, "{arrowup}");
     expect(input).toHaveValue("flow.encode");
-    userEvent.type(input, "{arrowup}");
+    await userEvent.type(input, "{arrowup}");
     expect(input).toHaveValue("foo");
-    userEvent.type(input, "{arrowdown}");
+    await userEvent.type(input, "{arrowdown}");
     expect(input).toHaveValue("flow.encode");
-    userEvent.type(input, "{arrowdown}");
+    await userEvent.type(input, "{arrowdown}");
     expect(input).toHaveValue("");
 });
