@@ -1,14 +1,16 @@
 import * as React from "react";
-import { useDispatch } from "react-redux";
 import FileChooser from "../common/FileChooser";
 import Dropdown, { Divider, MenuItem } from "../common/Dropdown";
 import * as flowsActions from "../../ducks/flows";
 import HideInStatic from "../common/HideInStatic";
-import { useAppSelector } from "../../ducks";
+import { useAppDispatch, useAppSelector } from "../../ducks";
+import { FilterName } from "../../ducks/ui/filter";
 
 export default React.memo(function FileMenu() {
-    const dispatch = useDispatch(),
-        filter = useAppSelector((state) => state.flows.filter);
+    const dispatch = useAppDispatch();
+    const filter = useAppSelector(
+        (state) => state.ui.filter[FilterName.Search],
+    );
     return (
         <Dropdown
             className="pull-left special"
@@ -51,7 +53,7 @@ export default React.memo(function FileMenu() {
             <HideInStatic>
                 <Divider />
                 <li>
-                    <a href="http://mitm.it/" target="_blank">
+                    <a href="http://mitm.it/" target="_blank" rel="noreferrer">
                         <i className="fa fa-fw fa-external-link" />
                         &nbsp;Install Certificates...
                     </a>
