@@ -36,6 +36,7 @@ class Row extends Component<RowProps> {
                     onEditDone={(newKey) =>
                         this.props.onEditDone([newKey, value])
                     }
+                    selectAllOnClick={true}
                 />
                 :&nbsp;
                 <ValueEditor
@@ -47,6 +48,7 @@ class Row extends Component<RowProps> {
                         this.props.onEditDone([key, newVal])
                     }
                     placeholder="empty"
+                    selectAllOnClick={true}
                 />
             </div>
         );
@@ -92,7 +94,7 @@ export default class KeyValueListEditor extends Component<
 
     static getDerivedStateFromProps(
         props: KeyValueListProps,
-        state: KeyValueListState
+        state: KeyValueListState,
     ): KeyValueListState | null {
         if (props.data !== state.initialList)
             return { currentList: props.data || [], initialList: props.data };
@@ -111,7 +113,9 @@ export default class KeyValueListEditor extends Component<
                     onEditDone={(newItem) => this.onEditDone(row, newItem)}
                     onClickEmptyArea={() => this.onClickEmptyArea(row)}
                     onTabNext={() => this.onTabNext(row)}
-                    ref={(e) => (this.rowRefs[row] = e)}
+                    ref={(e) => {
+                        this.rowRefs[row] = e;
+                    }}
                 />
             );
         });
@@ -126,7 +130,7 @@ export default class KeyValueListEditor extends Component<
                     onClick={(e) => {
                         e.preventDefault();
                         this.onClickEmptyArea(
-                            this.state.currentList.length - 1
+                            this.state.currentList.length - 1,
                         );
                     }}
                     className="kv-add-row fa fa-plus-square-o"
@@ -138,7 +142,7 @@ export default class KeyValueListEditor extends Component<
     };
 
     onEditDone = (row: number, newItem: Item) => {
-        let newList = [...this.state.currentList];
+        const newList = [...this.state.currentList];
         if (newItem[0]) {
             newList[row] = newItem;
         } else {
@@ -152,10 +156,10 @@ export default class KeyValueListEditor extends Component<
 
     onClickEmptyArea = (row: number) => {
         if (this.justFinishedEditing) return;
-        let newList = [...this.state.currentList];
+        const newList = [...this.state.currentList];
         newList.splice(row + 1, 0, ["", ""]);
         this.setState({ currentList: newList }, () =>
-            this.rowRefs[row + 1]?.nameInput.current?.startEditing()
+            this.rowRefs[row + 1]?.nameInput.current?.startEditing(),
         );
     };
 
@@ -165,7 +169,7 @@ export default class KeyValueListEditor extends Component<
         }
     };
 
-    onMouseDown = (e: React.MouseEvent) => {
+    onMouseDown = (_e: React.MouseEvent) => {
         this.justFinishedEditing = this.currentlyEditing;
     };
 }
