@@ -14,7 +14,7 @@ export type VScroll = {
 };
 
 export function calcVScroll(
-    opts: VScrollArgs | undefined = undefined
+    opts: VScrollArgs | undefined = undefined,
 ): VScroll {
     if (!opts) {
         return { start: 0, end: 0, paddingTop: 0, paddingBottom: 0 };
@@ -24,11 +24,10 @@ export function calcVScroll(
         opts;
     const viewportBottom = viewportTop + viewportHeight;
 
-    let start = 0;
-    let end = 0;
-
-    let paddingTop = 0;
-    let paddingBottom = 0;
+    let start = 0,
+        end = 0,
+        paddingTop = 0,
+        paddingBottom = 0;
 
     if (itemHeights) {
         let pos = 0;
@@ -62,16 +61,16 @@ export function calcVScroll(
     } else {
         // We may have removed a lot of rows since the last render,
         // which means viewportTop will move up.
-        let newViewportTop = Math.min(
+        const newViewportTop = Math.min(
             viewportTop,
-            Math.max(0, itemCount * rowHeight - viewportHeight)
+            Math.max(0, itemCount * rowHeight - viewportHeight),
         );
 
         // Make sure that we start at an even row so that CSS `:nth-child(even)` is preserved
         start = Math.max(0, Math.floor(newViewportTop / rowHeight) - 1) & ~1;
         end = Math.min(
             itemCount,
-            start + Math.ceil(viewportHeight / rowHeight) + 2
+            start + Math.ceil(viewportHeight / rowHeight) + 2,
         );
 
         paddingTop = start * rowHeight;
